<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>QApplication</name>
    <message>
        <source>MX Tweak</source>
        <translation type="obsolete">MX Tweak</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="obsolete">Deze app is enkel Xfce</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>HoofdScherm</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software (xrandr) Helderheid</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Hardware Backlight</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="30"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="56"/>
        <source>Display</source>
        <translation>Beeldscherm</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="61"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="52"/>
        <location filename="../defaultlook.cpp" line="67"/>
        <location filename="../defaultlook.cpp" line="558"/>
        <location filename="../defaultlook.cpp" line="565"/>
        <location filename="../defaultlook.cpp" line="582"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Xfce Instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Het paneel aanpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="77"/>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Paneel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configureer schermgedrag en snelkoppelingen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>Schermbeheer</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pas het uiterlijk van uw desktop aan&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Backup huidige paneel configuratie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Herstel gebackupte paneel configuratie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Herstel standaard paneel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Beïnvloedt 1e paneel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Laat paneel verticaal zien</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="365"/>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="370"/>
        <source>Top</source>
        <translation>Bovenin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="378"/>
        <source>Display panel horizontally</source>
        <translation>Laat paneel horizontaal zien</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="398"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="403"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="411"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Beïnvloedt alle panelen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vensterknoppen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="446"/>
        <location filename="../defaultlook.ui" line="549"/>
        <location filename="../defaultlook.ui" line="740"/>
        <location filename="../defaultlook.ui" line="877"/>
        <location filename="../defaultlook.ui" line="1000"/>
        <location filename="../defaultlook.ui" line="1007"/>
        <location filename="../defaultlook.ui" line="1099"/>
        <location filename="../defaultlook.ui" line="1168"/>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="469"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="483"/>
        <source>Theme Options</source>
        <translation>Thema Opties</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Sommige webpagina velden repareren wanneer het donkere thema gebruikt wordt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Firefox dark theme tweak</source>
        <translation>Firefox donker thema tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="523"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Repareer HexChat invoerveld in donker thema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="575"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="582"/>
        <source>Preview</source>
        <translation>Voorbeeld</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="589"/>
        <source>Remove User Theme Set</source>
        <translation>Verwijder Gebruiker Thema Set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="600"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Sla Huidige Instellingen op als Thema Set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="614"/>
        <location filename="../defaultlook.ui" line="760"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="635"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Start compton-conf configuratiegereedschap</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compton settings</source>
        <translation>Compton instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="662"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Instellingen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="665"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm Instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfmw (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="699"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Bewerkt compton.conf rechtstreeks in tekstverwerker</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="710"/>
        <source>Edit compton.conf</source>
        <translation>Bewerk compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="767"/>
        <source>Transparency and shadow options</source>
        <translation>Transparantie- en schaduwopties</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Veranderen van de VBlank modus kan wat screen tearing problemen verminderen. Zie Help voor meer informatie.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="785"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="790"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="795"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="800"/>
        <source>off</source>
        <translation>uit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1016"/>
        <source>Config Options</source>
        <translation>Configuratie Opties</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1024"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Herstel Lightdm (login scherm) naar systeem standaard thema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1031"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Herstel Thunar aangepaste rechts-klik acties naar systeem standaard</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1038"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Gebruik intel driver in plaats van standaard &quot;modesetting&quot; driver (vereist herstart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1045"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>NOOT: bestaande /etc/X11/xorg.conf.d/20-intel.conf zal gebackupped worden in de home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1052"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Gebruik tearvrij amdgpu optie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1059"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>NOOT: bestaande /etc/X11/xorg.conf.d/20-amd.conf zal gebackupped worden in de home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1066"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Gebruik tearvrij radeon driver optie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1073"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>NOOT: bestaande /etc/X11/xorg.conf.d/20-radeon.conf zal gebackupped worden in de home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="811"/>
        <source>Display</source>
        <translation>Beeldscherm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="836"/>
        <source>Hardware Backlight</source>
        <translation>Hardware Backlight</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="843"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Beeldscherm Instellingen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="870"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Kies Beeldscherm voor xrandr instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="903"/>
        <source>Resolution</source>
        <translation>Resolutie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="910"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Opslaan is per beeldscherm&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="913"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="920"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software (xrandr) Helderheid</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="927"/>
        <location filename="../defaultlook.ui" line="941"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="934"/>
        <source>GTK scaling</source>
        <translation>GTK schaling</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="961"/>
        <source>xrandr Scaling</source>
        <translation>xrandr Schaling</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1113"/>
        <source>Other</source>
        <translation>Overige</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1135"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1155"/>
        <source>Show systray (notification area) frame</source>
        <translation>Laat systeemtray (notificatiegebied) venster zien</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1179"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Laat schermen van alle werkgebieden in paneel zien</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1186"/>
        <source>Enable single-click on desktop</source>
        <translation>Schakel enkel-klik op desktop in</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1193"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Schakel slaapstand in in Afmeldmenu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1241"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Maak koppelen van interne schijven door niet-root gebruikers mogelijk</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1248"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1200"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   let op: voor slaapstand moet swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1121"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Schakel verkorten van lange bestandsnamen op de desktop uit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1207"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Schakel enkel-klik in Thunar Bestandbeheer in</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1128"/>
        <source>Password for administrative tasks:</source>
        <translation>Wachtwoord voor administratieve taken:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1227"/>
        <source>User</source>
        <translation>Gebruiker</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="53"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="557"/>
        <source>About MX Tweak</source>
        <translation>Over MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="558"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="559"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>App voor snelle standaard ui thema veranderingen en fijninstellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="561"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="562"/>
        <location filename="../defaultlook.cpp" line="565"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="563"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="594"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Klaar! Firefox kan een herstart vereisen om de veranderingen door te voeren</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="vanished">Deze app is enkel Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="746"/>
        <source>Panel settings</source>
        <translation>Paneel instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="747"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Uw huidige paneelinstellingen zijn gebackupt in een verborgen folder genaamd .restore in uw home folder (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1157"/>
        <source>settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1494"/>
        <source>Choose a theme set</source>
        <translation>Kies een thema set</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Verwijder Gebruiker Thema Set</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nieuwe Thema Set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Voer naam in voor nieuwe thema set</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Vensterknoppen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Uiterlijk&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Toon knopetiketten</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Toon platte knoppen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Toon handgreep</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sorteervolgorde:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Tijdstempel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Groeptitel en tijdstempel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Venstertitel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Groeptitel en venstertitel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Geen, sta sleep-en-plak toe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Gedrag&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Venstergroepering:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Altijd</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Actie bij middelklik:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Niets</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Sluit venster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimaliseer venster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Herstel geminimaliseerde vensters naar het huidige werkblad</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Teken vensterrand als de muisaanwijzer over een knop zweeft</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Wissel vensters met het muiswieltje</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filteren&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Toon vensters van alle werkbladen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Toon alleen geminimaliseerde vensters</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Toon vensters van alle monitors</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Pop-up Scherm</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Schermen gedurende verplaatsing</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Doorschijnendheid Instellingen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Schermdecoraties</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Laat schaduwen onder dock schermen zien</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Laat schaduwen onder pop-up schermen zien</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Schermen gedurende maatverandering</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Laat schaduwen onder reguliere schermen zien</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Kenmerk Instellingen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Laat schermen zien in plaats van iconen wanneer gerold wordt</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Laat volledig scherm overlayschermen rechtstreeks zien</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Inactieve schermen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Synchroniseer tekenen naar vertikale blanco</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor Instellingen</translation>
    </message>
</context>
</TS>
